[PATCH v2 3/5] wined3d: Replace WINED3DUSAGE_WRITEONLY with resource access flags.

Matteo Bruni mbruni at codeweavers.com
Thu Jan 31 06:17:23 CST 2019


Always allow read and write mapping of ddraw buffers:
test_vb_writeonly() depends on that.

Signed-off-by: Matteo Bruni <mbruni at codeweavers.com>
---
v2: Adapt to the changes to the previous patches.

A test coming right after these patches shows that D3DUSAGE_WRITEONLY
textures / surfaces are not a thing. That means that we don't need to
change d3dusage_from_wined3dusage() anymore since we now store the
usage flags into the d3d{8,9}_{vertex,index}buffer objects.

 dlls/d3d8/device.c         |  4 ++--
 dlls/d3d9/device.c         |  4 ++--
 dlls/ddraw/device.c        |  4 ++--
 dlls/ddraw/executebuffer.c |  2 +-
 dlls/ddraw/vertexbuffer.c  |  2 --
 dlls/wined3d/resource.c    | 13 ++++++-------
 dlls/wined3d/utils.c       |  1 -
 include/wine/wined3d.h     |  3 +--
 8 files changed, 14 insertions(+), 19 deletions(-)

diff --git a/dlls/d3d8/device.c b/dlls/d3d8/device.c
index 0a7f4775c96..d367f4200cc 100644
--- a/dlls/d3d8/device.c
+++ b/dlls/d3d8/device.c
@@ -2383,7 +2383,7 @@ static HRESULT d3d8_device_prepare_vertex_buffer(struct d3d8_device *device, UIN
         TRACE("Growing vertex buffer to %u bytes\n", size);
 
         desc.byte_width = size;
-        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY;
+        desc.usage = WINED3DUSAGE_DYNAMIC;
         desc.bind_flags = WINED3D_BIND_VERTEX_BUFFER;
         desc.access = WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_MAP_W;
         desc.misc_flags = 0;
@@ -2478,7 +2478,7 @@ static HRESULT d3d8_device_prepare_index_buffer(struct d3d8_device *device, UINT
         TRACE("Growing index buffer to %u bytes\n", size);
 
         desc.byte_width = size;
-        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY | WINED3DUSAGE_STATICDECL;
+        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_STATICDECL;
         desc.bind_flags = WINED3D_BIND_INDEX_BUFFER;
         desc.access = WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_MAP_W;
         desc.misc_flags = 0;
diff --git a/dlls/d3d9/device.c b/dlls/d3d9/device.c
index 49a86c0159a..98ada03af8b 100644
--- a/dlls/d3d9/device.c
+++ b/dlls/d3d9/device.c
@@ -2854,7 +2854,7 @@ static HRESULT d3d9_device_prepare_vertex_buffer(struct d3d9_device *device, UIN
         TRACE("Growing vertex buffer to %u bytes.\n", size);
 
         desc.byte_width = size;
-        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY;
+        desc.usage = WINED3DUSAGE_DYNAMIC;
         desc.bind_flags = WINED3D_BIND_VERTEX_BUFFER;
         desc.access = WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_MAP_W;
         desc.misc_flags = 0;
@@ -2959,7 +2959,7 @@ static HRESULT d3d9_device_prepare_index_buffer(struct d3d9_device *device, UINT
         TRACE("Growing index buffer to %u bytes.\n", size);
 
         desc.byte_width = size;
-        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY | WINED3DUSAGE_STATICDECL;
+        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_STATICDECL;
         desc.bind_flags = WINED3D_BIND_INDEX_BUFFER;
         desc.access = WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_MAP_W;
         desc.misc_flags = 0;
diff --git a/dlls/ddraw/device.c b/dlls/ddraw/device.c
index 4b58b75f3c2..af9f28d8cbf 100644
--- a/dlls/ddraw/device.c
+++ b/dlls/ddraw/device.c
@@ -3469,7 +3469,7 @@ static HRESULT d3d_device_prepare_vertex_buffer(struct d3d_device *device, UINT
         TRACE("Growing vertex buffer to %u bytes\n", size);
 
         desc.byte_width = size;
-        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY;
+        desc.usage = WINED3DUSAGE_DYNAMIC;
         desc.bind_flags = WINED3D_BIND_VERTEX_BUFFER;
         desc.access = WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_MAP_W;
         desc.misc_flags = 0;
@@ -3661,7 +3661,7 @@ static HRESULT d3d_device_prepare_index_buffer(struct d3d_device *device, UINT m
         TRACE("Growing index buffer to %u bytes\n", size);
 
         desc.byte_width = size;
-        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY | WINED3DUSAGE_STATICDECL;
+        desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_STATICDECL;
         desc.bind_flags = WINED3D_BIND_INDEX_BUFFER;
         desc.access = WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_MAP_W;
         desc.misc_flags = 0;
diff --git a/dlls/ddraw/executebuffer.c b/dlls/ddraw/executebuffer.c
index 4b4af63b915..f9082dc028c 100644
--- a/dlls/ddraw/executebuffer.c
+++ b/dlls/ddraw/executebuffer.c
@@ -129,7 +129,7 @@ HRESULT d3d_execute_buffer_execute(struct d3d_execute_buffer *buffer,
                     struct wined3d_buffer_desc desc;
 
                     desc.byte_width = new_size * sizeof(*indices);
-                    desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY | WINED3DUSAGE_STATICDECL;
+                    desc.usage = WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_STATICDECL;
                     desc.bind_flags = WINED3D_BIND_INDEX_BUFFER;
                     desc.access = WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_MAP_W;
                     desc.misc_flags = 0;
diff --git a/dlls/ddraw/vertexbuffer.c b/dlls/ddraw/vertexbuffer.c
index 3ad8f7e1bdd..d2c2f8ff804 100644
--- a/dlls/ddraw/vertexbuffer.c
+++ b/dlls/ddraw/vertexbuffer.c
@@ -119,8 +119,6 @@ static HRESULT d3d_vertex_buffer_create_wined3d_buffer(struct d3d_vertex_buffer
 
     desc.byte_width = buffer->size;
     desc.usage = WINED3DUSAGE_STATICDECL;
-    if (buffer->Caps & D3DVBCAPS_WRITEONLY)
-        desc.usage |= WINED3DUSAGE_WRITEONLY;
     if (dynamic)
         desc.usage |= WINED3DUSAGE_DYNAMIC;
     desc.bind_flags = WINED3D_BIND_VERTEX_BUFFER;
diff --git a/dlls/wined3d/utils.c b/dlls/wined3d/utils.c
index dd70d3fc2d5..7b422022138 100644
--- a/dlls/wined3d/utils.c
+++ b/dlls/wined3d/utils.c
@@ -4515,7 +4515,6 @@ const char *debug_d3dusage(DWORD usage)
 
     init_debug_buffer(&buffer, "0");
 #define WINED3DUSAGE_TO_STR(x) if (usage & x) { debug_append(&buffer, #x, " | "); usage &= ~x; }
-    WINED3DUSAGE_TO_STR(WINED3DUSAGE_WRITEONLY);
     WINED3DUSAGE_TO_STR(WINED3DUSAGE_SOFTWAREPROCESSING);
     WINED3DUSAGE_TO_STR(WINED3DUSAGE_DONOTCLIP);
     WINED3DUSAGE_TO_STR(WINED3DUSAGE_POINTS);
diff --git a/include/wine/wined3d.h b/include/wine/wined3d.h
index 06f4f76ef21..e09e4e1fce2 100644
--- a/include/wine/wined3d.h
+++ b/include/wine/wined3d.h
@@ -914,7 +914,6 @@ enum wined3d_shader_type
 #define WINED3D_BIND_DEPTH_STENCIL                              0x00000040
 #define WINED3D_BIND_UNORDERED_ACCESS                           0x00000080
 
-#define WINED3DUSAGE_WRITEONLY                                  0x00000008
 #define WINED3DUSAGE_SOFTWAREPROCESSING                         0x00000010
 #define WINED3DUSAGE_DONOTCLIP                                  0x00000020
 #define WINED3DUSAGE_POINTS                                     0x00000040
@@ -926,7 +925,7 @@ enum wined3d_shader_type
 #define WINED3DUSAGE_RESTRICT_SHARED_RESOURCE                   0x00002000
 #define WINED3DUSAGE_DMAP                                       0x00004000
 #define WINED3DUSAGE_TEXTAPI                                    0x10000000
-#define WINED3DUSAGE_MASK                                       0x10007bf8
+#define WINED3DUSAGE_MASK                                       0x10007bf0
 
 #define WINED3DUSAGE_SCRATCH                                    0x00400000
 #define WINED3DUSAGE_PRIVATE                                    0x00800000
diff --git a/dlls/wined3d/resource.c b/dlls/wined3d/resource.c
index 82e9019a0ed..90025e9648b 100644
--- a/dlls/wined3d/resource.c
+++ b/dlls/wined3d/resource.c
@@ -28,10 +28,9 @@
 WINE_DEFAULT_DEBUG_CHANNEL(d3d);
 WINE_DECLARE_DEBUG_CHANNEL(d3d_perf);
 
-static void resource_check_usage(DWORD usage)
+static void resource_check_usage(DWORD usage, unsigned int access)
 {
-    static const DWORD handled = WINED3DUSAGE_WRITEONLY
-            | WINED3DUSAGE_DYNAMIC
+    static const DWORD handled = WINED3DUSAGE_DYNAMIC
             | WINED3DUSAGE_STATICDECL
             | WINED3DUSAGE_OVERLAY
             | WINED3DUSAGE_SCRATCH
@@ -39,7 +38,7 @@ static void resource_check_usage(DWORD usage)
             | WINED3DUSAGE_LEGACY_CUBEMAP
             | ~WINED3DUSAGE_MASK;
 
     /* WINED3DUSAGE_WRITEONLY is supposed to result in write-combined mappings
      * being returned. OpenGL doesn't give us explicit control over that, but
      * the hints and access flags we set for typical access patterns on
      * dynamic resources should in theory have the same effect on the OpenGL
@@ -47,8 +46,8 @@ static void resource_check_usage(DWORD usage)
 
     if (usage & ~handled)
         FIXME("Unhandled usage flags %#x.\n", usage & ~handled);
-    if ((usage & (WINED3DUSAGE_DYNAMIC | WINED3DUSAGE_WRITEONLY)) == WINED3DUSAGE_DYNAMIC)
-        WARN_(d3d_perf)("WINED3DUSAGE_DYNAMIC used without WINED3DUSAGE_WRITEONLY.\n");
+    if (usage & WINED3DUSAGE_DYNAMIC && access & WINED3D_RESOURCE_ACCESS_MAP_R)
+        WARN_(d3d_perf)("WINED3DUSAGE_DYNAMIC used with WINED3D_RESOURCE_ACCESS_MAP_R.\n");
 }
 
 HRESULT resource_init(struct wined3d_resource *resource, struct wined3d_device *device,
@@ -82,7 +81,7 @@ HRESULT resource_init(struct wined3d_resource *resource, struct wined3d_device *
         {WINED3D_RTYPE_TEXTURE_3D,  0,                              WINED3D_GL_RES_TYPE_TEX_3D},
     };
 
-    resource_check_usage(usage);
+    resource_check_usage(usage, access);
 
     if (usage & WINED3DUSAGE_SCRATCH && access & WINED3D_RESOURCE_ACCESS_GPU)
     {
@@ -39,7 +38,7 @@ static void resource_check_usage(DWORD usage)
             | ~WINED3DUSAGE_MASK;
 
-    /* WINED3DUSAGE_WRITEONLY is supposed to result in write-combined mappings
+    /* Write-only CPU access is supposed to result in write-combined mappings
      * being returned. OpenGL doesn't give us explicit control over that, but
      * the hints and access flags we set for typical access patterns on
-- 
2.19.2




More information about the wine-devel mailing list